TextureDataType

Enum TextureDataType 

pub enum TextureDataType {
    BYTE = 5_120,
    UNSIGNED_BYTE = 5_121,
    SHORT = 5_122,
    UNSIGNED_SHORT = 5_123,
    INT = 5_124,
    UNSIGNED_INT = 5_125,
    FLOAT = 5_126,
}
The texture data type used by CGL These are reflections of OpenGL’s enum values You can also use the _i version of methods to pass integers directly instead of enums

Variants



BYTE = 5_120



UNSIGNED_BYTE = 5_121



SHORT = 5_122



UNSIGNED_SHORT = 5_123



INT = 5_124



UNSIGNED_INT = 5_125



FLOAT = 5_126