pub enum TextureFormat {
RED = 6_403,
GREEN = 6_404,
BLUE = 6_405,
ALPHA = 6_406,
RGB = 6_407,
RGBA = 6_408,
BGR = 32_992,
BGRA = 32_993,
}Expand description
The texture format used by CGL These are reflections of OpenGL’s enum values You can also use the _i version of methods to pass integers directly instead of enums
Variants
RED = 6_403
GREEN = 6_404
BLUE = 6_405
ALPHA = 6_406
RGB = 6_407
RGBA = 6_408
BGR = 32_992
BGRA = 32_993