pub enum TextureScalingMode {
NEAREST = 9_728,
LINEAR = 9_729,
NEAREST_MIPMAP_NEAREST = 9_984,
LINEAR_MIPMAP_NEAREST = 9_985,
NEAREST_MIPMAP_LINEAR = 9_986,
LINEAR_MIPMAP_LINEAR = 9_987,
}Expand description
The texture scaling mode used by CGL These are reflections of OpenGL’s enum values You can also use the _i version of methods to pass integers directly instead of enums
Variants
NEAREST = 9_728
LINEAR = 9_729
NEAREST_MIPMAP_NEAREST = 9_984
LINEAR_MIPMAP_NEAREST = 9_985
NEAREST_MIPMAP_LINEAR = 9_986
LINEAR_MIPMAP_LINEAR = 9_987