IVector4

Struct IVector4 

#[repr(C)]
pub struct IVector4 { pub x: i32, pub y: i32, pub z: i32, pub w: i32, }
A 4-dimensional vector with x, y, z and w components, all of which are i32.

Fields

x: i32y: i32z: i32w: i32

Implementations

Source

impl IVector4

pub fn new(x: i32, y: i32, z: i32, w: i32) -> IVector4

Creates a new IVector4 with the given x, y, z, and w components.

Arguments
  • x - The x component of the vector.
  • y - The y component of the vector.
  • z - The z component of the vector.
  • w - The w component of the vector.
Examples
use cgl_rs::math::IVector4;

let vec = IVector4::new(1, 2, 3, 4);
assert_eq!(vec.x, 1);
assert_eq!(vec.y, 2);
assert_eq!(vec.z, 3);
assert_eq!(vec.w, 4);
pub fn zero() -> IVector4

Returns a new IVector4 with all components set to 0.

Examples
use cgl_rs::math::IVector4;

let vec = IVector4::zero();
assert_eq!(vec.x, 0);
assert_eq!(vec.y, 0);
assert_eq!(vec.z, 0);
assert_eq!(vec.w, 0);