pub enum Event {
Key(Key, Action, i32, i32),
MouseButton(MouseButton, Action, i32),
MousePosition(f64, f64),
MouseScroll(f64, f64),
FramebufferSize(i32, i32),
WindowClose,
DragNDrop(Vec<String>),
}Expand description
Represents an event that can be received by a window, with each variant corresponding to a specific type of event.
Variants
Key(Key, Action, i32, i32)
MouseButton(MouseButton, Action, i32)
MousePosition(f64, f64)
MouseScroll(f64, f64)
FramebufferSize(i32, i32)
WindowClose
DragNDrop(Vec<String>)