pub enum TextureInternalFormat {
Show 23 variants
RGBA32F = 34_836,
RGB32F = 34_837,
RGBA16F = 34_842,
RGB16F = 34_843,
RGBA32UI = 36_208,
RGB32UI = 36_209,
RGBA16UI = 36_214,
RGB16UI = 36_215,
RGBA8UI = 36_220,
RGB8UI = 36_221,
RGBA32I = 36_226,
RGB32I = 36_227,
RGBA16I = 36_232,
RGB16I = 36_233,
RGBA8I = 36_238,
RGB8I = 36_239,
RED_INTEGER = 36_244,
GREEN_INTEGER = 36_245,
BLUE_INTEGER = 36_246,
RGB_INTEGER = 36_248,
RGBA_INTEGER = 36_249,
BGR_INTEGER = 36_250,
BGRA_INTEGER = 36_251,
}Expand description
The texture internal format used by CGL These are reflections of OpenGL’s enum values You can also use the _i version of methods to pass integers directly instead of enums
Variants
RGBA32F = 34_836
RGB32F = 34_837
RGBA16F = 34_842
RGB16F = 34_843
RGBA32UI = 36_208
RGB32UI = 36_209
RGBA16UI = 36_214
RGB16UI = 36_215
RGBA8UI = 36_220
RGB8UI = 36_221
RGBA32I = 36_226
RGB32I = 36_227
RGBA16I = 36_232
RGB16I = 36_233
RGBA8I = 36_238
RGB8I = 36_239
RED_INTEGER = 36_244
GREEN_INTEGER = 36_245
BLUE_INTEGER = 36_246
RGB_INTEGER = 36_248
RGBA_INTEGER = 36_249
BGR_INTEGER = 36_250
BGRA_INTEGER = 36_251